# TemplateSetNameViewer
#
# Release 0.01 (Oct 03, 2008)
#
# This software is provided as-is. You may use it for commercial or
# personal use. If you distribute it, please keep this notice intact.
#
# Copyright (c) 2004-2008 Yujiro Araki

package MT::Plugin::TemplateSetNameViewer;

use strict;
use warnings;
use MT;
use base qw( MT::Plugin );

our $VERSION = '0.01';

my $plugin = __PACKAGE__->new ({
    id   => 'templatesetnameviewer',
    name => 'TemplateSetNameViewer',
    description => '<MT_TRANS phrase="Display templateset name.">',
    doc_link => 'http://www.koikikukan.com/archives/2008/10/03-005555.php',
    author_name => 'Yujiro Araki',
    author_link => 'http://www.koikikukan.com/',
    l10n_class => 'TemplateSetNameViewer::L10N',
    version => $VERSION,
});
MT->add_plugin($plugin);

sub init_registry {
    my $plugin = shift;
    $plugin->registry({
        callbacks => {
             'MT::App::CMS::template_source.list_template' => \&display_template_set_id_list_template,
             'MT::App::CMS::template_param.list_template' => \&get_templateset_id,

             'MT::App::CMS::template_source.edit_template' => \&display_template_set_id_edit_template,
             'MT::App::CMS::template_param.edit_template' => \&get_templateset_id,

             'MT::App::CMS::template_source.list_widget' => \&display_template_set_id_list_widget,
             'MT::App::CMS::template_param.list_widget' => \&get_templateset_id,
        },
   });
}

our $data = <<HERE;
<mt:setvarblock name="templateset_name">
    <mt:if name="blog_id">
        <mt:loop name="template_set_loop"><mt:if name="selected"><mt:var name="label" escape="html"></mt:if></mt:loop>
    </mt:if>
</mt:setvarblock>
HERE

sub get_templateset_id {
    my ($cb, $app, $param, $tmpl) = @_;
    my $blog = $app->blog || return; # return if global template.

    my $sets = $app->registry("template_sets");
    $sets->{$_}{key} = $_ for keys %$sets;
    $sets = $app->filter_conditional_list([ values %$sets ]);

    my $existing_set = $blog->template_set || 'mt_blog';
    my @sets;
    foreach (@$sets) {
        my %set = %{$_};
        if ($set{key} eq $existing_set) {
            $set{selected} = 1;
            push @sets, \%set;
            last;
        }
    }
    $param->{'template_set_loop'} = \@sets;
}

sub display_template_set_id_list_template {
    my ($cb, $app, $template) = @_;

    my $old = <<HERE;
<mt:if name="blog_id"><mt:setvarblock name="page_title"><__trans phrase="Blog Templates"></mt:setvarblock><mt:else><mt:setvarblock name="page_title"><__trans phrase="Global Templates"></mt:setvarblock></mt:if>
HERE
    $old = quotemeta($old);

    my $new = <<HERE;
$data
<mt:if name="blog_id"><mt:setvarblock name="page_title"><__trans phrase="Blog Templates">
<mt:if tag="blogTemplateSetID">: <mt:var name="templateset_name" /></mt:if>
</mt:setvarblock><mt:else><mt:setvarblock name="page_title"><__trans phrase="Global Templates"></mt:setvarblock></mt:if>
HERE

    $$template =~ s/$old/$new/;
}

sub display_template_set_id_edit_template {
    my ($cb, $app, $template) = @_;

    my $old = <<HERE;
<mt:setvarblock name="page_title">
HERE
    $old = quotemeta($old);

    my $new = <<HERE;
$data
<mt:setvarblock name="page_title">
<mt:if name="blog_id"><mt:if tag="blogTemplateSetID"><mt:var name="templateset_name" />: </mt:if></mt:if>
HERE

    $$template =~ s/$old/$new/;
}

sub display_template_set_id_list_widget {
    my ($cb, $app, $template) = @_;

    my $old = <<HERE;
<mt:setvarblock name="page_title"><__trans phrase="Widgets"></mt:setvarblock>
HERE
    $old = quotemeta($old);

    my $new = <<HERE;
$data
<mt:setvarblock name="page_title"><__trans phrase="Widgets"><mt:if name="blog_id"><mt:if tag="blogTemplateSetID">: <mt:var name="templateset_name" /></mt:if></mt:if></mt:setvarblock>
HERE

    $$template =~ s/$old/$new/;
}

1;
